# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.5.0]
### Added
 - Added \_\_main\_\_ so Pool can be executed using `python -m hek_pool` or just `hek_pool` on some systems.

## [1.4.2]
### Changed
 - Fix readme not being accepted because it isn't RST.

## [1.4.1]
### Changed
 - Fix readme potentially breaking setup.

## [1.4.0]
### Changed
- Fix help_text not being generated if target folder is missing.
- Minor posix compatibility updates.

### Removed
 - **REMOVED SUPPORT FOR VERSIONS OF PYTHON BELOW 3.5**

## [1.3.1]
### Changelog
 - Fixed bug with pool window always moving slightly every re-open
